/** ============================================================================
MIT License

Copyright (c) 2023-2024 Institute for Automotive Engineering (ika), RWTH Aachen University

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
============================================================================= */

/** Auto-generated by https://github.com/ika-rwth-aachen/etsi_its_messages -----
python3 \
  utils/codegen/codegen-py/asn1ToConversionHeader.py \
  asn1/raw/cam_ts103900/CAM-PDU-Descriptions.asn \
  asn1/patched/cam_ts103900/cdd/ETSI-ITS-CDD.asn \
  -t \
  cam_ts \
  -o \
  etsi_its_conversion/etsi_its_cam_ts_conversion/include/etsi_its_cam_ts_conversion
----------------------------------------------------------------------------- */

/** ASN.1 Definition -----------------------------------------------------------
*
* This type contains detaild information of the Safety Car Container.
*
* It shall include the following components:
*
* @field lightBarSirenInUse: it indicates whether light-bar or a siren is in use by the vehicle originating the CAM.
*
* @field incidentIndication: the optional incident related to the roadworks to provide additional information of the roadworks zone.
*
* @field trafficRule: an optional rule indicates whether vehicles are allowed to overtake a safety car that is originating this CAM.
*
* @field speedLimit: an optional speed indicates whether a speed limit is applied to vehicles following the safety car. 
*
SafetyCarContainer ::= SEQUENCE {
	lightBarSirenInUse LightBarSirenInUse,
	incidentIndication CauseCodeV2 OPTIONAL,
	trafficRule TrafficRule OPTIONAL,
	speedLimit SpeedLimit OPTIONAL
}
----------------------------------------------------------------------------- */

#pragma once

#include <etsi_its_cam_ts_coding/cam_ts_SafetyCarContainer.h>
#include <etsi_its_cam_ts_conversion/convertCauseCodeV2.h>
#include <etsi_its_cam_ts_conversion/convertLightBarSirenInUse.h>
#include <etsi_its_cam_ts_conversion/convertSpeedLimit.h>
#include <etsi_its_cam_ts_conversion/convertTrafficRule.h>
#ifdef ROS1
#include <etsi_its_cam_ts_msgs/SafetyCarContainer.h>
namespace cam_ts_msgs = etsi_its_cam_ts_msgs;
#else
#include <etsi_its_cam_ts_msgs/msg/safety_car_container.hpp>
namespace cam_ts_msgs = etsi_its_cam_ts_msgs::msg;
#endif


namespace etsi_its_cam_ts_conversion {

void toRos_SafetyCarContainer(const cam_ts_SafetyCarContainer_t& in, cam_ts_msgs::SafetyCarContainer& out) {
  toRos_LightBarSirenInUse(in.lightBarSirenInUse, out.light_bar_siren_in_use);
  if (in.incidentIndication) {
    toRos_CauseCodeV2(*in.incidentIndication, out.incident_indication);
    out.incident_indication_is_present = true;
  }
  if (in.trafficRule) {
    toRos_TrafficRule(*in.trafficRule, out.traffic_rule);
    out.traffic_rule_is_present = true;
  }
  if (in.speedLimit) {
    toRos_SpeedLimit(*in.speedLimit, out.speed_limit);
    out.speed_limit_is_present = true;
  }
}

void toStruct_SafetyCarContainer(const cam_ts_msgs::SafetyCarContainer& in, cam_ts_SafetyCarContainer_t& out) {
  memset(&out, 0, sizeof(cam_ts_SafetyCarContainer_t));
  toStruct_LightBarSirenInUse(in.light_bar_siren_in_use, out.lightBarSirenInUse);
  if (in.incident_indication_is_present) {
    out.incidentIndication = (cam_ts_CauseCodeV2_t*) calloc(1, sizeof(cam_ts_CauseCodeV2_t));
    toStruct_CauseCodeV2(in.incident_indication, *out.incidentIndication);
  }
  if (in.traffic_rule_is_present) {
    out.trafficRule = (cam_ts_TrafficRule_t*) calloc(1, sizeof(cam_ts_TrafficRule_t));
    toStruct_TrafficRule(in.traffic_rule, *out.trafficRule);
  }
  if (in.speed_limit_is_present) {
    out.speedLimit = (cam_ts_SpeedLimit_t*) calloc(1, sizeof(cam_ts_SpeedLimit_t));
    toStruct_SpeedLimit(in.speed_limit, *out.speedLimit);
  }
}

}
